@@ -1,7 +1,7 @@
 package Plack::Response;
 use strict;
 use warnings;
-our $VERSION = '0.9989';
+our $VERSION = '0.9990';
 $VERSION = eval $VERSION;
 
 use Plack::Util::Accessor qw(body status);
@@ -138,6 +138,7 @@ sub _bake_cookie {
     push @cookie, "domain=" . $val->{domain}   if $val->{domain};
     push @cookie, "path=" . $val->{path}       if $val->{path};
     push @cookie, "expires=" . $self->_date($val->{expires}) if $val->{expires};
+    push @cookie, "max-age=" . $val->{"max-age"} if $val->{"max-age"};
     push @cookie, "secure"                     if $val->{secure};
     push @cookie, "HttpOnly"                   if $val->{httponly};
 
@@ -275,7 +276,8 @@ Returns a hash reference containing cookies to be set in the
 response. The keys of the hash are the cookies' names, and their
 corresponding values are a plain string (for C<value> with everything
 else defaults) or a hash reference that can contain keys such as
-C<value>, C<domain>, C<expires>, C<path>, C<httponly>, C<secure>.
+C<value>, C<domain>, C<expires>, C<path>, C<httponly>, C<secure>,
+C<max-age>.
 
 C<expires> can take a string or an integer (as an epoch time) and
 B<does not> convert string formats such as C<+3M>.
